
RELEASE_VERSION='0.3.1371376127'
BUILD_DATE='Fri Jul 12 13:47:06 UTC 2024'
BUILD_MACHINE_INFO='Linux runner-ykxhnyexq-project-28359933-concurrent-0 5.15.154+ #1 SMP Sat May 4 12:14:42 UTC 2024 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='7328794352'
GIT_COMMIT_SHA='295c5eb0ee1fa74ad3b38c617111fbf309c5f609'
GIT_BRANCH='main'
